==> antd-mobile-1.1.1.tgz: package/lib/switch/index.web.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _extends2=require('babel-runtime/helpers/extends');var _extends3=_interopRequireDefault(_extends2);var _defineProperty2=require('babel-runtime/helpers/defineProperty');var _defineProperty3=_interopRequireDefault(_defineProperty2);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _classnames=require('classnames');var _classnames2=_interopRequireDefault(_classnames);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var
Switch=function(_React$Component){(0,_inherits3["default"])(Switch,_React$Component);
function Switch(){(0,_classCallCheck3["default"])(this,Switch);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.onChange=function(e){
var checked=e.target.checked;
if(_this.props.onChange){
_this.props.onChange(checked);
}
};return _this;
}Switch.prototype.
render=function render(){var _classNames;var _props=
this.props,prefixCls=_props.prefixCls,style=_props.style,name=_props.name,checked=_props.checked,disabled=_props.disabled,className=_props.className,platform=_props.platform;
var isAndroid=platform==='android'||platform==='cross'&&!!navigator.userAgent.match(/Android/i);
var wrapCls=(0,_classnames2["default"])((_classNames={},(0,_defineProperty3["default"])(_classNames,''+
prefixCls,true),(0,_defineProperty3["default"])(_classNames,
className,className),(0,_defineProperty3["default"])(_classNames,
prefixCls+'-android',isAndroid),_classNames));

return _react2["default"].createElement('label',{className:wrapCls,style:style},
_react2["default"].createElement('input',(0,_extends3["default"])({type:'checkbox',name:name,className:prefixCls+'-checkbox'},disabled?{disabled:'disabled'}:'',{checked:checked,onChange:this.onChange})),
_react2["default"].createElement('div',{className:'checkbox'}));

};return Switch;}(_react2["default"].Component);exports["default"]=Switch;

Switch.defaultProps={
prefixCls:'am-switch',
name:'',
checked:false,
disabled:false,
onChange:function onChange(){},
platform:'cross'};module.exports=exports['default'];

==> antd-mobile-1.1.2.tgz: package/lib/switch/index.web.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _extends2=require('babel-runtime/helpers/extends');var _extends3=_interopRequireDefault(_extends2);var _defineProperty2=require('babel-runtime/helpers/defineProperty');var _defineProperty3=_interopRequireDefault(_defineProperty2);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _classnames=require('classnames');var _classnames2=_interopRequireDefault(_classnames);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var
Switch=function(_React$Component){(0,_inherits3["default"])(Switch,_React$Component);
function Switch(){(0,_classCallCheck3["default"])(this,Switch);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.onChange=function(e){
var checked=e.target.checked;
if(_this.props.onChange){
_this.props.onChange(checked);
}
};return _this;
}Switch.prototype.
render=function render(){var _classNames;var _props=
this.props,prefixCls=_props.prefixCls,style=_props.style,name=_props.name,checked=_props.checked,disabled=_props.disabled,className=_props.className,platform=_props.platform;
var isAndroid=platform==='android'||platform==='cross'&&!!navigator.userAgent.match(/Android/i);
var wrapCls=(0,_classnames2["default"])((_classNames={},(0,_defineProperty3["default"])(_classNames,''+
prefixCls,true),(0,_defineProperty3["default"])(_classNames,
className,className),(0,_defineProperty3["default"])(_classNames,
prefixCls+'-android',isAndroid),_classNames));

return _react2["default"].createElement('label',{className:wrapCls,style:style,role:'switch'},
_react2["default"].createElement('input',(0,_extends3["default"])({type:'checkbox',name:name,className:prefixCls+'-checkbox'},disabled?{disabled:'disabled'}:'',{checked:checked,onChange:this.onChange})),
_react2["default"].createElement('div',{className:'checkbox'}));

};return Switch;}(_react2["default"].Component);exports["default"]=Switch;

Switch.defaultProps={
prefixCls:'am-switch',
name:'',
checked:false,
disabled:false,
onChange:function onChange(){},
platform:'cross'};module.exports=exports['default'];
